/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.flowservicecomponent;

import java.util.UUID;

import org.tinygroup.cepcore.EventProcessor;
import org.tinygroup.context.Context;
import org.tinygroup.event.Event;
import org.tinygroup.event.ServiceRequest;
import org.tinygroup.flow.ComponentInterface;
import org.tinygroup.plugin.PluginManager;
import org.tinygroup.springutil.SpringUtil;

public class CallServiceComponent implements ComponentInterface {

	private String serviceId;
	private String serviceName;
	private String groupId;
	private String artifactId;
	private String version;

	public String getGroupId() {
		return groupId;
	}

	public void setGroupId(String groupId) {
		this.groupId = groupId;
	}

	public String getArtifactId() {
		return artifactId;
	}

	public void setArtifactId(String artifactId) {
		this.artifactId = artifactId;
	}

	public String getVersion() {
		return version;
	}

	public void setVersion(String version) {
		this.version = version;
	}

	public String getServiceId() {
		return serviceId;
	}

	public void setServiceId(String serviceId) {
		this.serviceId = serviceId;
	}

	public String getServiceName() {
		return serviceName;
	}

	public void setServiceName(String serviceName) {
		this.serviceName = serviceName;
	}

	public void execute(Context context) {
		PluginManager pluginManager = SpringUtil.getBean(
				"pluginManager");
		EventProcessor channel = (EventProcessor) pluginManager.getService(
				pluginManager.getPluginInfo("simplechannel"), "simplechannel");
		Event event = getEvent(context);
		channel.process(event);
	}

	private Event getEvent(Context context) {
		Event event = new Event();
		event.setEventId(UUID.randomUUID().toString());
		ServiceRequest serviceRequest = new ServiceRequest();
		serviceRequest.setContext(context);
		if (notNull(serviceId)) {
			serviceRequest.setServiceId(serviceId);
		}
		if (notNull(serviceName)) {
			serviceRequest.setName(serviceName);
		}
		if (notNull(artifactId)) {
			serviceRequest.setArtifactId(artifactId);
		}
		if (notNull(groupId)) {
			serviceRequest.setGroupId(groupId);
		}
		if (notNull(version)) {
			serviceRequest.setVersion(version);
		}
		event.setServiceRequest(serviceRequest);
		return event;
	}

	private boolean notNull(String str) {
		return str != null && !"".equals(str);
	}

}
